MethodChannelSimcards class

An implementation of SimcardsPlatform that uses method channels.

Inheritance

Constructors

MethodChannelSimcards()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<String?>
override
getSimCards() → Future<List<SimCard>>
Returns Available SimCards
override
hasPermission() → Future<bool>
Checks whether the READ_PHONE_STATE Permission is granted
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermission() → Future<void>
Requests the READ_PHONE_STATE permission
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited